package com.fs.his.service;

import java.util.List;
import java.util.Map;

import com.fs.his.domain.FsPackage;
import com.fs.his.param.FsPackageListUParam;
import com.fs.his.param.FsPackageParam;
import com.fs.his.vo.*;

/**
 * 套餐包Service接口
 *
 * @author fs
 * @date 2023-08-25
 */
public interface IFsPackageService
{
    /**
     * 查询套餐包
     *
     * @param packageId 套餐包主键
     * @return 套餐包
     */
    public FsPackage selectFsPackageByPackageId(Long packageId);

    /**
     * 查询套餐包列表
     *
     * @param fsPackage 套餐包
     * @return 套餐包集合
     */
    public List<FsPackage> selectFsPackageList(FsPackage fsPackage);

    /**
     * 新增套餐包
     *
     * @param fsPackage 套餐包
     * @return 结果
     */
    public int insertFsPackage(FsPackage fsPackage);

    /**
     * 修改套餐包
     *
     * @param fsPackage 套餐包
     * @return 结果
     */
    public int updateFsPackage(FsPackage fsPackage);

    /**
     * 批量删除套餐包
     *
     * @param packageIds 需要删除的套餐包主键集合
     * @return 结果
     */
    public int deleteFsPackageByPackageIds(Long[] packageIds);

    /**
     * 删除套餐包信息
     *
     * @param packageId 套餐包主键
     * @return 结果
     */
    public int deleteFsPackageByPackageId(Long packageId);

    List<OptionsVO> selectAllPackageList();

    List<FsPackageListVO> selectFsPackageListVO(FsPackageParam fsPackage);

    String importData(List<FsPackage> list);

    FsPackageVO selectFsPackageByPackageIdVO(Long packageId);

    List<FsPackageExcelVO> selectFsPackageListExcelVO(FsPackage fsPackage);

    List<FsPackageListUVO> selectFsPackageListUVO(FsPackageListUParam param);

    List<FsPackageListVO> selectFsPackageListVByName(String fsPackage);

    int updatePackagesStatus(Long[] packageIds, Long status);

    String convertImageToJpg(String imgUrl, Long packageId);

    /**
     * 根据套餐id查询icd名字
     * @param packageId
     * @return icdName
     */
    List<String> selectIcdNameByPackageId(Long packageId);

    List<FsPackage> selectFsPackageListByIds(Long[] packageIds);

    int bulkCopyFsPackageByPackage(Long[] packageIds);

    /**
     * 获取套餐包选择列表
     */
    List<FsPackageChooseVO> getChoosePackageListByMap(Map<String, Object> params);
}
